.. xpaw documentation master file, created by
   sphinx-quickstart on Thu Mar 16 11:08:48 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


============================
xpaw |version| documentation
============================

Overview
========

xpaw is a web scraping framework, used to crawl web pages and extract structured data from them.

Getting started
===============

.. toctree::
   :maxdepth: 2

   intro/install
   intro/quickstart

All the rest
============

.. toctree::
   :maxdepth: 1

   changelog
